@@ -1,7 +1,10 @@
 from operator import attrgetter
 from itertools import repeat
 from copy import deepcopy
-from mock import patch
+try:
+    from unittest.mock import patch
+except ImportError:
+    from mock import patch
 import platform
 import sys
 import re
@@ -776,6 +779,49 @@ def testValues_find_object_branches_04(parse_c01):
     result_correct = [[None, None, None, None, None]]
     assert test_result == result_correct
 
+def testValues_find_object_branches_05():
+    """Basic test: find_object_branches() - Test that non-existent regex child levels are returned if allow_none=True (see Github Issue #178)"""
+    test_data = ['thisis',
+        '    atest',
+        '        ofbranchsearch',
+        'thisis',
+        '    atest',
+        '        matchthis',
+        ]
+
+    parse = CiscoConfParse(test_data)
+
+    branchspec = (r"^this", r"^\s+atest", r"^\s+matchthis")
+    test_result = parse.find_object_branches(branchspec, allow_none=True)
+
+    assert len(test_result)==2
+    assert test_result[0][0].text.strip() == "thisis"
+    assert test_result[0][1].text.strip() == "atest"
+    assert test_result[0][2] is None
+    assert test_result[1][0].text.strip() == "thisis"
+    assert test_result[1][1].text.strip() == "atest"
+    assert test_result[1][2].text.strip() == "matchthis"
+
+def testValues_find_object_branches_06():
+    """Basic test: find_object_branches() - Test that non-existent regex child levels are not returned if allow_none=False (see Github Issue #178)"""
+    test_data = ['thisis',
+        '    atest',
+        '        ofbranchsearch',
+        'thisis',
+        '    atest',
+        '        matchthis',
+        ]
+
+    parse = CiscoConfParse(test_data)
+
+    branchspec = (r"^this", r"^\s+atest", r"^\s+matchthis")
+    test_result = parse.find_object_branches(branchspec, allow_none=False)
+
+    assert len(test_result)==1
+    assert test_result[0][0].text.strip() == "thisis"
+    assert test_result[0][1].text.strip() == "atest"
+    assert test_result[0][2].text.strip() == "matchthis"
+
 
 def testValues_find_objects_w_parents(parse_c01):
     c01_children_w_parents_switchport = [
